@@ -4,6 +4,8 @@ use Moose;
 use MooseX::StrictConstructor;
 use namespace::autoclean;
 
+with 'Data::Collector::Commands';
+
 has 'name'      => ( is => 'ro', isa => 'Str' );
 has 'connected' => (
     is        => 'rw',
@@ -11,17 +13,14 @@ has 'connected' => (
     default   => 0,
 );
 
-has 'test' => ( is => 'ro', isa => 'Str', default => '/usr/bin/test' );
-has 'echo' => ( is => 'ro', isa => 'Str', default => '/bin/echo'     );
-
 # basic overridable methods
 sub run         { die 'No default run method' }
 sub connect     {1}
 sub disconnect  {1}
 sub file_exists {
     my ( $self, $file ) = @_;
-    my $test = $self->test;
-    my $echo = $self->echo;
+    my $test = $self->get_command('test');
+    my $echo = $self->get_command('echo');
     my $cmd  = "$test -f $file ; $echo \$?";
     return $self->run($cmd);
 }
@@ -126,14 +125,6 @@ subclass it if you're doing it differently (or don't want to support it).
 
     $engine->check_files('file');
 
-You can also change the path of C<test> and C<echo> from C</usr/bin/test> and
-C</bin/echo> (respectively) to whatever you want using I<engine_args>.
-
-    engine_args => {
-        test => '/usr/local/bin/test',
-        echo => '/usr/local/bin/echo',
-    }
-
 =head1 AUTHOR
 
 Sawyer X, C<< <xsawyerx at cpan.org> >>
